@@ -5,7 +5,7 @@ use warnings;
 use utf8;
 use Regexp::Grammars;
 
-our $VERSION = '0.38';
+our $VERSION = '0.39';
 
 sub new {
 	my ($class) = @_;
@@ -386,7 +386,7 @@ sub PT::BoolOperator::X {
 
 sub PT::BoolOperands::X {
     my ($class, $className) = @_;
-    return (	   $class->{Number}
+    return (	   $class->{RealNumber}
 		|| $class->{String}
 		|| $class->{ScalarVariable}
 		|| $class->{ArrayElement}
@@ -473,6 +473,12 @@ sub PT::Number::X {
     return $number;
 }
 
+sub PT::RealNumber::X {
+    my ($class, $className) = @_;
+    my $realNumber = $class->{''};
+    return $realNumber;
+}
+
 sub PT::String::X {
     my ($class, $className) = @_;
     my $stringValue = $class->{StringValue}->X($className);
@@ -521,7 +527,7 @@ sub PT::ListElements::X {
 
 sub PT::ListElement::X {
     my ($class, $className) = @_;
-    return (       $class->{Number}
+    return (       $class->{RealNumber}
                 || $class->{String}
                 || $class->{ArrayList}
                 || $class->{HashRef}
@@ -580,7 +586,7 @@ sub PT::PairKey::X {
 
 sub PT::PairValue::X {
     my ($class, $className) = @_;
-    return (	   $class->{Number}
+    return (	   $class->{RealNumber}
 		|| $class->{String}
 		|| $class->{ArrayList}
 		|| $class->{HashRef}
@@ -619,7 +625,7 @@ sub PT::Parameters::X {
 
 sub PT::Param::X {
     my ($class, $className) = @_;
-    return (       $class->{Number}
+    return (       $class->{RealNumber}
                 || $class->{String}
                 || $class->{VariableName}
                 || $class->{ArrayElement}
@@ -673,7 +679,7 @@ sub PT::ScalarVariable::X {
 
 sub PT::RHS::X {
     my ($class, $className) = @_;
-    return (       $class->{Number}
+    return (       $class->{RealNumber}
                 || $class->{FunctionReturn}
                 || $class->{ArrayElement}
                 || $class->{HashElement}
@@ -889,7 +895,7 @@ sub PT::CalcExpression::X {
 
 sub PT::CalcOperands::X {
     my ($class, $className) = @_;
-    return (       $class->{Number}
+    return (       $class->{RealNumber}
                 || $class->{ScalarVariable}
                 || $class->{ArrayElement}
                 || $class->{HashElement} )->X($className);
@@ -1010,8 +1016,8 @@ sub PT::LogicalOr::X {
 
 my $parser = qr {
     #<nocontext:>
-    <debug: off>
-    #<logfile: parserLog>
+	<debug: off>
+	#<logfile: parserLog>
 	#<timeout: 100>
 
     <Lang>
@@ -1056,7 +1062,7 @@ my $parser = qr {
     <objrule:  PT::If>                         <TokenIf> <LParen> <BoolExpression> <RParen> <CodeBlock>
     <objrule:  PT::BoolExpression>             <BoolOperands> <BoolOperatorExpression>?
     <objrule:  PT::BoolOperatorExpression>     <BoolOperator> <BoolOperands>
-    <objrule:  PT::BoolOperands>               <Number> | <String> | <ScalarVariable> | <ArrayElement> | <HashElement>
+    <objrule:  PT::BoolOperands>               <RealNumber> | <String> | <ScalarVariable> | <ArrayElement> | <HashElement>
 											   | <ClassFunctionReturn> | <FunctionReturn>
     <objrule:  PT::BoolOperator>               <GreaterThan> | <LessThan> | <Equals> | <GreaterThanEquals> | <LessThanEquals>
                                                | <StringEquals> | <StringNotEquals> | <NotEqulas> | <LogicalAnd> | <LogicalOr>
@@ -1076,6 +1082,7 @@ my $parser = qr {
     <objtoken: PT::VariableName>               [a-zA-Z]+?
     <objrule:  PT::Value>                      <RHS>
     <objtoken: PT::Number>                     [0-9]+
+	<objtoken: PT::RealNumber>                 [-]?\d+\.?\d+|\d+
     <objrule:  PT::String>                     <LQuote> <StringValue> <RQuote>
     <objrule:  PT::LQuote>                     <Quote>
     <objrule:  PT::RQuote>                     <Quote>
@@ -1084,7 +1091,7 @@ my $parser = qr {
     <objrule:  PT::ArrayDeclaration>           <Var> <VariableName> <Equal> <ArrayList> <SemiColon>
     <objrule:  PT::ArrayList>                  <LBracket> <ListElements> <RBracket>
     <objrule:  PT::ListElements>               .{0} | <[ListElement]>+ % <Comma>
-    <objrule:  PT::ListElement>                <Number> | <String> | <ClassFunctionReturn> | <FunctionReturn>
+    <objrule:  PT::ListElement>                <RealNumber> | <String> | <ClassFunctionReturn> | <FunctionReturn>
 											   | <ArrayElement> | <HashElement> | <ArrayList> | <HashRef> | <VariableName>
 
     <objrule:  PT::HashDeclaration>            <Var> <VariableName> <Equal> <HashRef> <SemiColon>
@@ -1092,18 +1099,18 @@ my $parser = qr {
     <objrule:  PT::KeyValuePairs>              .{0} | <[KeyValue]>+ % <Comma>
     <objrule:  PT::KeyValue>                   <PairKey> <Colon> <PairValue>
     <objrule:  PT::PairKey>                    <Number> | <String>
-    <objrule:  PT::PairValue>                  <Number> | <String> | <ClassFunctionReturn> | <FunctionReturn>
+    <objrule:  PT::PairValue>                  <RealNumber> | <String> | <ClassFunctionReturn> | <FunctionReturn>
 											   | <ArrayElement> | <HashElement> | <ArrayList> | <HashRef> | <VariableName>
 
     <objrule:  PT::FunctionCall>               <FunctionName> <LParen> <Parameters>? <RParen> <SemiColon>
     <objrule:  PT::Parameters>                 <[Param]>+ % <Comma>
-    <objrule:  PT::Param>                      <Number> | <String> | <VariableName> | <ArrayElement> | <HashElement>
+    <objrule:  PT::Param>                      <RealNumber> | <String> | <VariableName> | <ArrayElement> | <HashElement>
 
     <objrule:  PT::Assignment>                 <ScalarAssignment> | <ArrayAssignment> | <HashAssignment> | <AccessorAssignment>
 
     <objrule:  PT::ScalarAssignment>           <ScalarVariable> <Equal> <RHS> <SemiColon>
     <objtoken: PT::ScalarVariable>             [a-zA-Z]+
-    <objrule:  PT::RHS>                        <Number> | <FunctionReturn> | <ArrayElement> | <HashElement>
+    <objrule:  PT::RHS>                        <RealNumber> | <FunctionReturn> | <ArrayElement> | <HashElement>
                                                | <ScalarVariable> | <Calc> | <ArrayList> | <HashRef> | <ClassAccessor>
                                                | <OtherClassAccesor> | <ClassFunctionReturn> | <String> | <STDIN>
     <objrule:  PT::FunctionReturn>             <FunctionName> <LParen> <Parameters>? <RParen>
@@ -1130,7 +1137,7 @@ my $parser = qr {
 
     <objrule:  PT::Calc>                       <CalcExpression>
     <objrule:  PT::CalcExpression>             <[CalcOperands]>+ % <[CalcOperator]>
-    <objrule:  PT::CalcOperands>               <Number> | <ScalarVariable> | <ArrayElement> | <HashElement>
+    <objrule:  PT::CalcOperands>               <RealNumber> | <ScalarVariable> | <ArrayElement> | <HashElement>
     <objtoken: PT::CalcOperator>               <Plus> | <Minus> | <Multiply> | <Divide>
 
     <objrule:  PT::Return>                     <TokenReturn> <RHS>? <SemiColon>
